==> landtax-1.0.0-20160518.023814-5-sources.jar: cn/gtmap/landtax/entity/SSjYdqc.java <==
package cn.gtmap.landtax.entity;

import javax.persistence.*;
import java.math.BigDecimal;

/**
 * 疑点清册信息
 *
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2014/7/2
 */
@MappedSuperclass
public abstract class SSjYdqc {

    @Column
    private String sgydm;
    @Column
    private String ssjg;
    @Column
    private String ssnf;
    @Column
    private String ydtype;
    @Column
    private String sssq;
    @Column
    private String qxdm;

    @Column
    private String glbm;

    @Column
    private String hsqk;//核实情况
    @Column
    private String rwid;//工作流实例id
    @Column
    private BigDecimal cybl;
    @Column
    private BigDecimal endYjse;
    @Column
    private BigDecimal endSbse;
    @Column
    private BigDecimal endCybl;



    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "JBB_ID")
    private SwDjJbb swDjJbb;

    public String getSgydm() {
        return sgydm;
    }

    public void setSgydm(String sgydm) {
        this.sgydm = sgydm;
    }

    public String getSsjg() {
        return ssjg;
    }

    public void setSsjg(String ssjg) {
        this.ssjg = ssjg;
    }

    public String getSsnf() {
        return ssnf;
    }

    public void setSsnf(String ssnf) {
        this.ssnf = ssnf;
    }

    public String getYdtype() {
        return ydtype;
    }

    public void setYdtype(String ydtype) {
        this.ydtype = ydtype;
    }

    public String getSssq() {
        return sssq;
    }

    public void setSssq(String sssq) {
        this.sssq = sssq;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public SwDjJbb getSwDjJbb() {
        return swDjJbb;
    }

    public void setSwDjJbb(SwDjJbb swDjJbb) {
        this.swDjJbb = swDjJbb;
    }

    public String getGlbm() {
        return glbm;
    }

    public void setGlbm(String glbm) {
        this.glbm = glbm;
    }



    public String getHsqk() {
        return hsqk;
    }

    public void setHsqk(String hsqk) {
        this.hsqk = hsqk;
    }

    public String getRwid() {
        return rwid;
    }

    public void setRwid(String rwid) {
        this.rwid = rwid;
    }

    public BigDecimal getCybl() {
        return cybl;
    }

    public void setCybl(BigDecimal cybl) {
        this.cybl = cybl;
    }

    public BigDecimal getEndYjse() {
        return endYjse;
    }

    public void setEndYjse(BigDecimal endYjse) {
        this.endYjse = endYjse;
    }

    public BigDecimal getEndSbse() {
        return endSbse;
    }

    public void setEndSbse(BigDecimal endSbse) {
        this.endSbse = endSbse;
    }

    public BigDecimal getEndCybl() {
        return endCybl;
    }

    public void setEndCybl(BigDecimal endCybl) {
        this.endCybl = endCybl;
    }
}

==> landtax-1.0.0-20180601.023313-26-sources.jar: cn/gtmap/landtax/entity/SSjYdqc.java <==
package cn.gtmap.landtax.entity;

import javax.persistence.*;
import java.math.BigDecimal;

/**
 * 疑点清册信息
 *
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2014/7/2
 */
@MappedSuperclass
public abstract class SSjYdqc {

    @Column
    private String sgydm;
    @Column
    private String ssjg;
    @Column
    private String ssnf;
    @Column
    private String ydtype;
    @Column
    private String sssq;
    @Column
    private String qxdm;

    @Column
    private String glbm;
    @Column
    private String nsrsbh;

    @Column
    private String hsqk;//核实情况
    @Column
    private String rwid;//工作流实例id
    @Column
    private BigDecimal cybl;
    @Column
    private BigDecimal endYjse;
    @Column
    private BigDecimal endSbse;
    @Column
    private BigDecimal endCybl;



    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "JBB_ID")
    private SwDjJbb swDjJbb;
    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }


    public String getSgydm() {
        return sgydm;
    }

    public void setSgydm(String sgydm) {
        this.sgydm = sgydm;
    }

    public String getSsjg() {
        return ssjg;
    }

    public void setSsjg(String ssjg) {
        this.ssjg = ssjg;
    }

    public String getSsnf() {
        return ssnf;
    }

    public void setSsnf(String ssnf) {
        this.ssnf = ssnf;
    }

    public String getYdtype() {
        return ydtype;
    }

    public void setYdtype(String ydtype) {
        this.ydtype = ydtype;
    }

    public String getSssq() {
        return sssq;
    }

    public void setSssq(String sssq) {
        this.sssq = sssq;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public SwDjJbb getSwDjJbb() {
        return swDjJbb;
    }

    public void setSwDjJbb(SwDjJbb swDjJbb) {
        this.swDjJbb = swDjJbb;
    }

    public String getGlbm() {
        return glbm;
    }

    public void setGlbm(String glbm) {
        this.glbm = glbm;
    }



    public String getHsqk() {
        return hsqk;
    }

    public void setHsqk(String hsqk) {
        this.hsqk = hsqk;
    }

    public String getRwid() {
        return rwid;
    }

    public void setRwid(String rwid) {
        this.rwid = rwid;
    }

    public BigDecimal getCybl() {
        return cybl;
    }

    public void setCybl(BigDecimal cybl) {
        this.cybl = cybl;
    }

    public BigDecimal getEndYjse() {
        return endYjse;
    }

    public void setEndYjse(BigDecimal endYjse) {
        this.endYjse = endYjse;
    }

    public BigDecimal getEndSbse() {
        return endSbse;
    }

    public void setEndSbse(BigDecimal endSbse) {
        this.endSbse = endSbse;
    }

    public BigDecimal getEndCybl() {
        return endCybl;
    }

    public void setEndCybl(BigDecimal endCybl) {
        this.endCybl = endCybl;
    }
}
